==> haskell-trifecta-1.7.1.1-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.7.1.1
id: trifecta-1.7.1.1-4xVruC1CLMi8vhDoboiiEm
key: trifecta-1.7.1.1-4xVruC1CLMi8vhDoboiiEm
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 89eeb119e1bc1eec4b787c9a452a46e4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/trifecta-1.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/trifecta-1.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/trifecta-1.7.1.1
hs-libraries: HStrifecta-1.7.1.1-4xVruC1CLMi8vhDoboiiEm
depends:
    ansi-wl-pprint-0.6.8.2-7yGyojXGz04K9UP4nqZeWn
    ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT array-0.5.2.0
    base-4.10.1.0 blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    blaze-html-0.9.0.1-DmW7Dgz0bGH6bjMUMT1XF
    blaze-markup-0.8.2.0-8grjG6g3OXI4E0IG9asDfS bytestring-0.10.8.2
    charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK
    comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP containers-0.5.10.2
    deepseq-1.4.3.0 fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD
    ghc-prim-0.5.1.1 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    lens-4.15.4-81WesV5SaQU8mHfsXlwvGV mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parsers-0.12.8-HWANkX3BzC76qYVtiHl4mO
    profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A
    reducers-3.12.2-BidbFflf23rIAbpxaVnm95
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: ansi-wl-pprint-0.6.8.2-7yGyojXGz04K9UP4nqZeWn=aaa526befd51a63f6a2b80e6ced721af
             ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT=0aa3d84ed37feddcfc4971478d436776
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             blaze-html-0.9.0.1-DmW7Dgz0bGH6bjMUMT1XF=e2fc24073886c12f340191d7d20d8f49
             blaze-markup-0.8.2.0-8grjG6g3OXI4E0IG9asDfS=fc34522ff2b8baf7b23fd99c42be7f28
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK=b495c830ee170b168cbeaec4ce237bfe
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD=d7351ce314efe14eb0244de484921c11
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             lens-4.15.4-81WesV5SaQU8mHfsXlwvGV=82abfc425102f60fc18da76ef0099869
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parsers-0.12.8-HWANkX3BzC76qYVtiHl4mO=bf98ccfa66590d7e526ea51481cd8102
             profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A=908044a83daa6649d4a3896409f07b7b
             reducers-3.12.2-BidbFflf23rIAbpxaVnm95=7dadc21be1d7e5bf443ebcd81022b0e8
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-1.7.1.1-51-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.7.1.1
id: trifecta-1.7.1.1-H7ooJ01Dti08IMoJ0emjyD
key: trifecta-1.7.1.1-H7ooJ01Dti08IMoJ0emjyD
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 830d6c604193f3f6b6f51819eaa2e0fb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/trifecta-1.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/trifecta-1.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/trifecta-1.7.1.1
hs-libraries: HStrifecta-1.7.1.1-H7ooJ01Dti08IMoJ0emjyD
depends:
    ansi-wl-pprint-0.6.8.2-7yGyojXGz04K9UP4nqZeWn
    ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT array-0.5.2.0
    base-4.10.1.0 blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    blaze-html-0.9.0.1-4OJxrIJKFBtLtijPqODCyq
    blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3 bytestring-0.10.8.2
    charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK
    comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP containers-0.5.10.2
    deepseq-1.4.3.0 fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD
    ghc-prim-0.5.1.1 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    lens-4.15.4-CcieSmu1RSJLB2Tu4Je8zo mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parsers-0.12.8-97PGzAI1UFX6TG9Ms0nBQY
    profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2
    reducers-3.12.2-4b5Pmlno3NV62wT0krGSKn
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: ansi-wl-pprint-0.6.8.2-7yGyojXGz04K9UP4nqZeWn=aaa526befd51a63f6a2b80e6ced721af
             ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT=0aa3d84ed37feddcfc4971478d436776
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             blaze-html-0.9.0.1-4OJxrIJKFBtLtijPqODCyq=5e2cd3879602ce26e9a3d86b5343f1fb
             blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3=89f2a92574468b60b114253ec4e21006
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             charset-0.3.7.1-AhCg0zwbkUDBkZUyiOxjAK=b495c830ee170b168cbeaec4ce237bfe
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD=d7351ce314efe14eb0244de484921c11
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             lens-4.15.4-CcieSmu1RSJLB2Tu4Je8zo=debbb5c6e3ce2aad169db2abcbc3ef09
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parsers-0.12.8-97PGzAI1UFX6TG9Ms0nBQY=f528a243b289adef26af938494bec3b5
             profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2=20f9843906eb1a5fcfc2baccf1835360
             reducers-3.12.2-4b5Pmlno3NV62wT0krGSKn=262498bfdcc4e93346de01478d1bcb52
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
